@@ -1,14 +1,14 @@
 #' Reduce portfolio by merging redundant date ranges
 #'
-#' @description Transform all the date ranges together as a set to produce a new set of date ranges. Ranges separated by a gap of at least \code{min.gapwidth} days are not merged.
+#' @description Transform all the date ranges together as a set to produce a new set of date ranges. Ranges separated by a gap of at least `min.gapwidth` days are not merged.
 #'
 #' @param df data.frame
-#' @param begin name of column \code{df} with begin dates
-#' @param end name of column in \code{df} with end dates
-#' @param ... names of columns in \code{df} used to group date ranges by
-#' @param agg_cols list with columns in \code{df} to aggregate by (defaults to NULL)
+#' @param begin name of column `df` with begin dates
+#' @param end name of column in `df` with end dates
+#' @param ... names of columns in `df` used to group date ranges by
+#' @param agg_cols list with columns in `df` to aggregate by (defaults to NULL)
 #' @param agg aggregation type (defaults to "sum")
-#' @param min.gapwidth ranges separated by a gap of at least \code{min.gapwidth} days are not merged. Defaults to 5.
+#' @param min.gapwidth ranges separated by a gap of at least `min.gapwidth` days are not merged. Defaults to 5.
 #'
 #' @import data.table
 #' @importFrom dplyr lead
@@ -17,15 +17,15 @@
 #'
 #' @author Martin Haringa
 #'
-#' @details This function is adopted from \code{IRanges::reduce()}.
+#' @details This function is adopted from `IRanges::reduce()`.
 #'
-#' @return An object of class \code{"reduce"}.
-#' The function \code{summary} is used to obtain and print a summary of the results.
-#' An object of class \code{"reduce"} is a list usually containing at least the following elements:
+#' @return An object of class `"reduce"`.
+#' The function `summary` is used to obtain and print a summary of the results.
+#' An object of class `"reduce"` is a list usually containing at least the following elements:
 #' \item{df}{data frame with reduced time periods}
-#' \item{begin}{name of column in \code{df} with begin dates}
-#' \item{end}{name of column in \code{df} with end dates}
-#' \item{cols}{names of columns in \code{df} used to group date ranges by}
+#' \item{begin}{name of column in `df` with begin dates}
+#' \item{end}{name of column in `df` with end dates}
+#' \item{cols}{names of columns in `df` used to group date ranges by}
 #'
 #' @examples
 #' portfolio <- structure(list(policy_nr = c("12345", "12345", "12345", "12345",
@@ -57,14 +57,14 @@ reduce <- function(df, begin, end, ..., agg_cols = NULL, agg = "sum", min.gapwid
   start_dt = end_dt = aggcols0 = NULL # due to NSE notes in R CMD check
 
   if (!lubridate::is.Date(df[[.begin]]) | !lubridate::is.Date(df[[.end]])) {
-    stop("Columns begin and end should be Date objects. Use e.g. lubridate::ymd() to create Date object.")
+    stop("Columns begin and end should be Date objects. Use e.g. lubridate::ymd() to create Date object.", call. = FALSE)
   }
 
   if (anyNA(df[[.begin]])) {
-    stop("NA values in data.table 'begin' column: '", .begin, "'. All rows with NA values in the range columns must be removed for reduce() to work.")
+    stop("NA values in data.table 'begin' column: '", .begin, "'. All rows with NA values in the range columns must be removed for reduce() to work.", call. = FALSE)
   }
   else if (anyNA(df[[.end]])) {
-    stop("NA values in data.table 'end' column: '", .end, "'. All rows with NA values in the range columns must be removed for reduce() to work.")
+    stop("NA values in data.table 'end' column: '", .end, "'. All rows with NA values in the range columns must be removed for reduce() to work.", call. = FALSE)
   }
 
   splitvars <- substitute(list(...))[-1]
@@ -74,7 +74,7 @@ reduce <- function(df, begin, end, ..., agg_cols = NULL, agg = "sum", min.gapwid
   aggcols0 <- sapply(aggvars, deparse)
 
   if ( length(cols0) == 0 ){
-    stop("define columns to group date ranges by")
+    stop("define columns to group date ranges by", call. = FALSE)
   }
 
   cols <- c(cols0, .begin, .end)
@@ -134,9 +134,9 @@ as.data.frame.reduce <- function(x, ...) {
 
 #' Automatically create a summary for objects obtained from reduce()
 #'
-#' @description Takes an object produced by \code{reduce()}, and counts new and lost customers.
+#' @description Takes an object produced by `reduce()`, and counts new and lost customers.
 #'
-#' @param object reduce object produced by \code{reduce()}
+#' @param object reduce object produced by `reduce()`
 #' @param period a character string indicating the period to aggregate on. Four options are available: "quarters", "months", "weeks", and "days" (the default option)
 #' @param ... names of columns to aggregate counts by
 #' @param name The name of the new column in the output. If omitted, it will default to count.
@@ -173,7 +173,7 @@ as.data.frame.reduce <- function(x, ...) {
 summary.reduce <- function(object, ..., period = "days", name = "count"){
 
   if (!inherits(object, "reduce")) {
-    stop("summary.reduce requires a reduce object, use object = object")
+    stop("summary.reduce requires a reduce object, use object = object", call. = FALSE)
   }
 
   df <- object
@@ -185,7 +185,7 @@ summary.reduce <- function(object, ..., period = "days", name = "count"){
   by_end <- end
 
   if (!period %in% c("years", "year", "quarters", "quarter", "months", "month", "weeks", "week", "day", "days")){
-    stop("period is not valid: choose 'year', 'quarter', 'month', 'week', or 'day'")
+    stop("period is not valid: choose 'year', 'quarter', 'month', 'week', or 'day'", call. = FALSE)
   }
 
   splitvars <- substitute(list(...))[-1]
@@ -251,7 +251,7 @@ summary.reduce <- function(object, ..., period = "days", name = "count"){
   }
 
   if( name != "count" ){
-    if ( !is.character(name) ) stop ( "Column name should be a character" )
+    if ( !is.character(name) ) stop ( "Column name should be a character", call. = FALSE )
     names(df)[names(df) == 'count'] <- name
   }
 
